@@ -1,16 +1,15 @@
+# encoding: utf-8
+
 """Basic dispatch routing."""
 
-
 from api import Dialect
-
-from webob.exc import *
+from web.core.http import HTTPNotImplemented
 
 
 __all__ = ['route']
 log = __import__('logging').getLogger(__name__)
 
 
-
 def route(root, method, expects):
     last = None
     part = root
